abacusai.chatllm_referral_invite — AbacusAI documentation

# abacusai.chatllm_referral_invite

## Classes

`ChatllmReferralInvite` | The response of the Chatllm Referral Invite for different emails

## Module Contents

class abacusai.chatllm_referral_invite.ChatllmReferralInvite(client, userAlreadyExists=None, successfulInvites=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The response of the Chatllm Referral Invite for different emails

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - userAlreadyExists (list) – List of user emails not successfullt invited, because they are already registered users.

    - successfulInvites (list) – List of users successfully invited.

  user_already_exists
  successful_invites
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict